@@ -13,7 +13,7 @@ def check_events(config, base_dir, plate, astrs, boosts, end, pause, scene_butto
                 exit()
 
             if event.type == pygame.KEYDOWN and event.key == pygame.K_ESCAPE:
-                config['sub_scene'] = 'pause'
+                scene_buttons.get_by_instance(PauseButton).press()
 
             elif event.type == pygame.KEYDOWN and event.key == pygame.K_SPACE:
                 if plate.rect.top >= plate.screen_rect.top + 50 and not plate.flip:
@@ -41,8 +41,6 @@ def check_events(config, base_dir, plate, astrs, boosts, end, pause, scene_butto
                 exit()
 
             elif event.type == pygame.KEYDOWN and event.key == pygame.K_ESCAPE:
-                scene_buttons.leave_buttons()
-                scene_buttons.enter_buttons('lobby', 'lobby')
                 scene_buttons.get_by_instance(EndLobbyButton).press()
 
             elif event.type == pygame.MOUSEBUTTONDOWN:
@@ -61,10 +59,17 @@ def check_events(config, base_dir, plate, astrs, boosts, end, pause, scene_butto
             elif event.type == pygame.MOUSEBUTTONDOWN:
                 x, y = pygame.mouse.get_pos()
 
-                scene_buttons.perform_point_collides((x, y))
+                pause_lobby_button = scene_buttons.get_by_instance(PauseLobbyButton)
+                if pause_lobby_button.rect.collidepoint((x, y)):
+                    defeat(plate, astrs, boosts, end, config, base_dir)
+                    config['scene'] = 'game'
+                    config['sub_scene'] = 'pause'
+                    pause_lobby_button.press()
+                else:
+                    scene_buttons.perform_point_collides((x, y))
 
 
-def spawn(screen, base_dir, config, tick, plate, astrs, boosts):
+def spawn(screen, base_dir, config, plate, astrs, boosts):
     # Spawn asteroid
     if len(astrs) == 0 or astrs.sprites()[-1].rect.x < config['mode'][0] - 200:
         astr = Asteroid(screen, base_dir, config)
@@ -73,7 +78,7 @@ def spawn(screen, base_dir, config, tick, plate, astrs, boosts):
         astrs.add(astr)
 
     # Spawn flying asteroid if difficulty >= middle
-    if config['score'] >= 10 and config['score'] % 5 == 0 and config['user']['difficulty'] >= 1:
+    if config['ns'].score >= 10 and config['ns'].score % 5 == 0 and config['user']['difficulty'] >= 1:
         for sprite in astrs:
             if sprite.name == 'flying':
                 break
@@ -81,7 +86,7 @@ def spawn(screen, base_dir, config, tick, plate, astrs, boosts):
             astrs.add(FlyingAsteroid(screen, base_dir, config))
 
     # Spawn boost
-    if config['score'] >= boosts.next_spawn:
+    if config['ns'].score >= boosts.next_spawn:
         boosts.next_spawn += randint(4, 8)
 
         choices = {'time': TimeBoost, 'double': DoubleBoost, 'shield': ShieldBoost}
@@ -107,20 +112,22 @@ def spawn(screen, base_dir, config, tick, plate, astrs, boosts):
         boosts.add(boost)
 
 
-def update(screen, config, base_dir, bg, plate, astrs, boosts, score, end, pause, tick, pause_buttons, end_buttons, scene_buttons):
+def update(screen, config, base_dir, bg, plate, astrs, boosts, score, end, pause, pause_buttons, end_buttons, scene_buttons):
     if config['sub_scene'] == 'game':
-        if tick % 2 == 0:
-            bg.update()
-
+        bg.update()
         bg.blit()
 
-        if tick % (config['FPS'] * 7) == 0:
+        scene_buttons.draw()
+
+        config['ns'].current_time += config['ns'].dt / 30
+        if config['ns'].current_time > 7:
+            config['ns'].current_time = 0
             if 'time' in boosts:
                 boosts.get('time').speed += 1
             else:
-                config['speed'] += 1
+                config['ns'].speed += 1
 
-        spawn(screen, base_dir, config, tick, plate, astrs, boosts)
+        spawn(screen, base_dir, config, plate, astrs, boosts)
 
         for astr in astrs:
             if astr.rect.right < 0 or astr.rect.top > config['mode'][1]:
@@ -129,9 +136,9 @@ def update(screen, config, base_dir, bg, plate, astrs, boosts, score, end, pause
                     pygame.mixer.Sound(plate.sounds['score']).play()
 
                 if 'double' in boosts:
-                    config['score'] += 2
+                    config['ns'].score += 2
                 else:
-                    config['score'] += 1
+                    config['ns'].score += 1
 
         for astr in astrs:
             astr.update()
@@ -143,7 +150,7 @@ def update(screen, config, base_dir, bg, plate, astrs, boosts, score, end, pause
             boost.update()
             boost.blit()
 
-        score.msg = f"score: {config['score']}"
+        score.msg = f"score: {config['ns'].score}"
         score.update()
         score.blit()
 
@@ -198,16 +205,17 @@ def check_collides(config, base_dir, astrs, boosts, plate, end):
 
 
 def defeat(plate, astrs, boosts, end, config, base_dir):
-    config['score_list'].append((config['score'], config['user']['nick']))
+    config['score_list'].append((config['ns'].score, config['user']['nick']))
     config.filter_score()
     config.save()
 
-    end.score = config['score']
+    end.score = config['ns'].score
     plate.reset()
     astrs.empty()
     boosts.empty()
 
-    config['speed'] = 2
-    config['score'] = 0
+    config['ns'].speed = 2
+    config['ns'].current_time = 0
+    config['ns'].score = 0
     config['scene'] = 'game'
     config['sub_scene'] = 'end'
