@@ -9,14 +9,9 @@ def check_events(config, base_dir):
             exit()
 
 
-def update(screen, config, text, tick):
-    screen.fill((0, 0, 0))
-
-    if tick % (config['FPS'] * 4) == 0:
-        config['scene'] = config['sub_scene'] = 'lobby'
-
-    if tick % (config['FPS'] * 2) == 0:
-        text.msg = 'With love'
-
+def update(screen, config, text, pb):
     text.update()
     text.blit()
+
+    pb.update()
+    pb.blit()
